#ifndef NT2_INCLUDE_FUNCTIONS_OPTIONS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_OPTIONS_HPP_INCLUDED

#include <nt2/linalg/include/functions/options.hpp>

#endif
